@@ -10,6 +10,7 @@
 #' For background information about flux footprints and considerations around the time scale of footprint calculations, see Amiro 1998: https://citeseerx.ist.psu.edu/viewdoc/download?doi=10.1.1.922.4124&rep=rep1&type=pdf
 #'
 #' @param filepath One of: a folder containing NEON EC H5 files, a zip file of DP4.00200.001 data downloaded from the NEON data portal, a folder of DP4.00200.001 data downloaded by the neonUtilities::zipsByProduct() function, or a single NEON EC H5 file. Filepath can only contain files for a single site. [character]
+#' @param progress T or F: should progress bars be printed? Defaults to TRUE. [logical]
 
 #' @details Given a filepath containing H5 files of expanded package DP4.00200.001 data, extracts flux footprint data and creates a raster.
 
@@ -34,7 +35,8 @@
 
 ##############################################################################################
 
-footRaster <- function(filepath) {
+footRaster <- function(filepath,
+                       progress=TRUE) {
   
   # first check for rhdf5 package
   if(!requireNamespace("rhdf5", quietly=T)) {
@@ -120,13 +122,12 @@ footRaster <- function(filepath) {
   # make empty list for location/dimension data
   locAttr <- list()
   
-  # make empty messages
-  messages <- character()
-  
   # set up progress bar
-  writeLines(paste0("Extracting data"))
-  pb <- utils::txtProgressBar(style=3)
-  utils::setTxtProgressBar(pb, 0)
+  if(isTRUE(progress)) {
+    message(paste0("Extracting data"))
+    pb <- utils::txtProgressBar(style=3)
+    utils::setTxtProgressBar(pb, 0)
+  }
 
   # extract footprint data from each file
   for(i in 1:length(files)) {
@@ -180,7 +181,7 @@ footRaster <- function(filepath) {
                                           'stat', sep='/'))
       # check for internal consistency
       if(length(unique(oriAttr$distReso))!=1) {
-        messages <- c(messages,'Resolution attribute is inconsistent. Rasters are unscaled.\n')
+        message('Resolution attribute is inconsistent. Rasters are unscaled.')
         locAttr$distReso <- 0
       } else {
         locAttr$distReso <- unique(oriAttr$distReso)
@@ -200,24 +201,28 @@ footRaster <- function(filepath) {
       newAttr$distReso <- newOri$distReso
       
       if(unique(newOri$distReso)!=locAttr$distReso) {
-        messages <- c(messages, 'Resolution attribute is inconsistent. Rasters are unscaled.\nCheck input data, inputs may have included multiple sites.\n')
+        message('Resolution attribute is inconsistent. Rasters are unscaled.\nCheck input data, inputs may have included multiple sites.')
         locAttr$distReso <- 0
       } else {
         if(!all(c(newAttr$LatTow, newAttr$LonTow, 
                   newAttr$ZoneUtm)==c(locAttr$LatTow,
                                       locAttr$LonTow,
                                       locAttr$ZoneUtm))) {
-          messages <- c(messages, 'Resolution attribute is inconsistent. Rasters are unscaled.\nCheck input data, inputs may have included multiple sites.\n')
+          message('Resolution attribute is inconsistent. Rasters are unscaled.\nCheck input data, inputs may have included multiple sites.')
           locAttr$distReso <- 0
         }
       }
       
     }
     
-    utils::setTxtProgressBar(pb, i/length(files))
+    if(isTRUE(progress)) {
+      utils::setTxtProgressBar(pb, i/length(files))
+    }
     
   }
-  close(pb)
+  if(isTRUE(progress)) {
+    close(pb)
+  }
  
   allGrids <- unlist(gridList, recursive=F)
   
@@ -259,8 +264,6 @@ footRaster <- function(filepath) {
   masterRaster <- c(summaryRaster, masterRaster)
   names(masterRaster)[1] <- paste(site, "summary", sep=".")
   
-  cat(messages)
-  
   return(masterRaster)
   
 }
